@@ -21,7 +21,8 @@ from typing import Optional
 import requests
 
 SUPPORTED_TYPE_REGISTRY_PRESETS = ('canvas', 'default', 'development', 'kusama', 'polkadot', 'rococo', 'metadata_types',
-                                   'substrate-node-template', 'westend', 'statemint', 'statemine', 'test')
+                                   'substrate-node-template', 'westend', 'statemint', 'statemine', 'karura',
+                                   'moonriver', 'moonbase-alpha', 'test')
 
 ONLINE_BASE_URL = 'https://raw.githubusercontent.com/polkascan/py-scale-codec/v1.0/scalecodec/type_registry/'
 
